==> 0.0.12-beta.tar.gz: android/src/main/java/com/weebkun/speedq_printer/SpeedqPrinterPlugin.java <==
package com.weebkun.speedq_printer;

import android.content.Context;

import androidx.annotation.NonNull;

import com.squareup.moshi.Moshi;

import java.util.List;
import java.util.Map;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;

/** SpeedqPrinterPlugin */
public class SpeedqPrinterPlugin implements FlutterPlugin, MethodCallHandler{
    /// The MethodChannel that will the communication between Flutter and native Android
    ///
    /// This local reference serves to register the plugin with the Flutter Engine and unregister it
    /// when the Flutter Engine is detached from the Activity
    private MethodChannel channel;
    private Context context;
    public final Moshi moshi = new Moshi.Builder().build();

    @Override
    public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
        channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "speedq_printer");
        channel.setMethodCallHandler(this);
        context = flutterPluginBinding.getApplicationContext();
    }

    @Override
    public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {

        final Map<String, Object> arguments = call.arguments();

        switch(call.method) {
            case "getPlatformVersion":
                result.success("Android " + android.os.Build.VERSION.RELEASE);
                break;
            case "init":
                BluetoothManager.bindService(context);
                result.success(null);
            case "getPairedDevices":
                result.success(moshi.adapter(Device[].class).toJson(BluetoothManager.getPairedDevices()));
                break;
            case "connect":
                BluetoothManager.bindService(context);
                BluetoothManager.connect(((String) arguments.get("mac")));
                result.success(null);
                break;
            case "print":
                BluetoothManager.printText(((String) arguments.get("message")));
                result.success(null);
                break;
            case "printNewLine":
                BluetoothManager.printNewLine();
                result.success(null);
                break;
            case "printCenter":
                if (arguments.containsKey("message")) {
                    String message = (String) arguments.get("message");
                    int size = (int) arguments.get("size");
                    BluetoothManager.printCenter(message, size);
                } else {
                    result.error("invalid_argument", "argument 'message' not found", null);
                }
                break;
            case "printLeft":
                if (arguments.containsKey("message")) {
                    String message = (String) arguments.get("message");
                    int size = (int) arguments.get("size");
                    BluetoothManager.printLeft(message, size);
                } else {
                    result.error("invalid_argument", "argument 'message' not found", null);
                }
                break;
            case "printRight":
                if (arguments.containsKey("message")) {
                    String message = (String) arguments.get("message");
                    int size = (int) arguments.get("size");
                    BluetoothManager.printRight(message, size);
                } else {
                    result.error("invalid_argument", "argument 'message' not found", null);
                }
                break;
            case "print3Column":
                if (arguments.containsKey("string1")) {
                    String string1 = (String) arguments.get("string1");
                    String string2 = (String) arguments.get("string2");
                    String string3 = (String) arguments.get("string3");
                    int size = (int) arguments.get("size");
                    BluetoothManager.print3Column(string1, string2,string3, size);
                } else {
                    result.error("invalid_argument", "argument 'message' not found", null);
                }
                break;
        }
    }

    @Override
    public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
        channel.setMethodCallHandler(null);
    }
}

==> 0.0.15-beta.tar.gz: android/src/main/java/com/weebkun/speedq_printer/SpeedqPrinterPlugin.java <==
package com.weebkun.speedq_printer;

import android.app.Application;
import android.bluetooth.BluetoothAdapter;
import android.bluetooth.BluetoothDevice;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.util.Log;

import androidx.annotation.NonNull;

import com.squareup.moshi.Moshi;

import java.util.List;
import java.util.Map;
import java.util.logging.StreamHandler;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;

/** SpeedqPrinterPlugin */
public class SpeedqPrinterPlugin implements FlutterPlugin, MethodCallHandler, RequestPermissionsResultListener, ActivityAware{
    /// The MethodChannel that will the communication between Flutter and native Android
    ///
    /// This local reference serves to register the plugin with the Flutter Engine and unregister it
    /// when the Flutter Engine is detached from the Activity
    private MethodChannel channel;
    private EventChannel stateChannel;
    private Context context;
    private EventSink statusSink;
    public final Moshi moshi = new Moshi.Builder().build();

    @Override
    public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
        channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "speedq_printer");
        channel.setMethodCallHandler(this);

        context = flutterPluginBinding.getApplicationContext();
    }

    @Override
    public void onAttachedToActivity(@NonNull ActivityPluginBinding binding) {
        activityBinding = binding;
        stateChannel = new EventChannel(flutterPluginBinding.getBinaryMessenger(), "state");
        stateChannel.setStreamHandler(stateStreamHandler);
        activityBinding.addRequestPermissionsResultListener(this);
    }

    @Override
    public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {

        final Map<String, Object> arguments = call.arguments();

        switch(call.method) {
            case "getPlatformVersion":
                result.success("Android " + android.os.Build.VERSION.RELEASE);
                break;
            case "init":
                BluetoothManager.bindService(context);
                result.success(null);
            case "getPairedDevices":
                result.success(moshi.adapter(Device[].class).toJson(BluetoothManager.getPairedDevices()));
                break;
            case "connect":
                BluetoothManager.bindService(context);
                BluetoothManager.connect(((String) arguments.get("mac")));
                result.success(null);
                break;
            case "print":
                BluetoothManager.printText(((String) arguments.get("message")));
                result.success(null);
                break;
            case "printNewLine":
                BluetoothManager.printNewLine();
                result.success(null);
                break;
            case "printCenter":
                if (arguments.containsKey("message")) {
                    String message = (String) arguments.get("message");
                    int size = (int) arguments.get("size");
                    BluetoothManager.printCenter(message, size);
                } else {
                    result.error("invalid_argument", "argument 'message' not found", null);
                }
                break;
            case "printLeft":
                if (arguments.containsKey("message")) {
                    String message = (String) arguments.get("message");
                    int size = (int) arguments.get("size");
                    BluetoothManager.printLeft(message, size);
                } else {
                    result.error("invalid_argument", "argument 'message' not found", null);
                }
                break;
            case "printRight":
                if (arguments.containsKey("message")) {
                    String message = (String) arguments.get("message");
                    int size = (int) arguments.get("size");
                    BluetoothManager.printRight(message, size);
                } else {
                    result.error("invalid_argument", "argument 'message' not found", null);
                }
                break;
            case "print3Column":
                if (arguments.containsKey("string1")) {
                    String string1 = (String) arguments.get("string1");
                    String string2 = (String) arguments.get("string2");
                    String string3 = (String) arguments.get("string3");
                    int size = (int) arguments.get("size");
                    BluetoothManager.print3Column(string1, string2,string3, size);
                } else {
                    result.error("invalid_argument", "argument 'message' not found", null);
                }
                break;
        }
    }

    @Override
    public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
        channel.setMethodCallHandler(null);
    }

    private final StreamHandler stateStreamHandler = new StreamHandler() {

        private final BroadcastReceiver mReceiver = new BroadcastReceiver() {
            @Override
            public void onReceive(Context context, Intent intent) {
                final String action = intent.getAction();

                Log.d("Printer Plugin", action);

                if (BluetoothAdapter.ACTION_STATE_CHANGED.equals(action)) {
                    statusSink.success(intent.getIntExtra(BluetoothAdapter.EXTRA_STATE, -1));
                } else if (BluetoothDevice.ACTION_ACL_CONNECTED.equals(action)) {
                    statusSink.success(1);
                } else if (BluetoothDevice.ACTION_ACL_DISCONNECTED.equals(action)) {
                    statusSink.success(0);
                }
            }
        };

        @Override
        public void onListen(Object o, EventSink eventSink) {
            statusSink = eventSink;
            context.registerReceiver(mReceiver, new IntentFilter(BluetoothAdapter.ACTION_STATE_CHANGED));

            context.registerReceiver(mReceiver, new IntentFilter(BluetoothDevice.ACTION_ACL_CONNECTED));

            context.registerReceiver(mReceiver, new IntentFilter(BluetoothDevice.ACTION_ACL_DISCONNECTED));
        }

        @Override
        public void onCancel(Object o) {
            statusSink = null;
            context.unregisterReceiver(mReceiver);
        }
    };

}
